# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class StoriesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_story_for_task(self, body, task_gid, **kwargs):  # noqa: E501
        """Create a story on a task  # noqa: E501

        Adds a story to a task. This endpoint currently only allows for comment stories to be created. The comment will be authored by the currently authenticated user, and timestamped when the server receives the request.  Returns the full record for the new story added to the task.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_story_for_task(body, task_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TaskGidStoriesBody body: The story to create. (required)
        :param str task_gid: The task to operate on. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_story_for_task_with_http_info(body, task_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.create_story_for_task_with_http_info(body, task_gid, **kwargs)  # noqa: E501
            return data

    def create_story_for_task_with_http_info(self, body, task_gid, **kwargs):  # noqa: E501
        """Create a story on a task  # noqa: E501

        Adds a story to a task. This endpoint currently only allows for comment stories to be created. The comment will be authored by the currently authenticated user, and timestamped when the server receives the request.  Returns the full record for the new story added to the task.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_story_for_task_with_http_info(body, task_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TaskGidStoriesBody body: The story to create. (required)
        :param str task_gid: The task to operate on. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'task_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_story_for_task" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_story_for_task`")  # noqa: E501
        # verify the required parameter 'task_gid' is set
        if ('task_gid' not in params or
                params['task_gid'] is None):
            raise ValueError("Missing the required parameter `task_gid` when calling `create_story_for_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_gid' in params:
            path_params['task_gid'] = params['task_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/tasks/{task_gid}/stories', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StoryResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_story(self, story_gid, **kwargs):  # noqa: E501
        """Delete a story  # noqa: E501

        Deletes a story. A user can only delete stories they have created.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_story(story_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str story_gid: Globally unique identifier for the story. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_story_with_http_info(story_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_story_with_http_info(story_gid, **kwargs)  # noqa: E501
            return data

    def delete_story_with_http_info(self, story_gid, **kwargs):  # noqa: E501
        """Delete a story  # noqa: E501

        Deletes a story. A user can only delete stories they have created.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_story_with_http_info(story_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str story_gid: Globally unique identifier for the story. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['story_gid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_story" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'story_gid' is set
        if ('story_gid' not in params or
                params['story_gid'] is None):
            raise ValueError("Missing the required parameter `story_gid` when calling `delete_story`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'story_gid' in params:
            path_params['story_gid'] = params['story_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/stories/{story_gid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_stories_for_task(self, task_gid, **kwargs):  # noqa: E501
        """Get stories from a task  # noqa: E501

        Returns the compact records for all stories on the task.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_stories_for_task(task_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_gid: The task to operate on. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_stories_for_task_with_http_info(task_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_stories_for_task_with_http_info(task_gid, **kwargs)  # noqa: E501
            return data

    def get_stories_for_task_with_http_info(self, task_gid, **kwargs):  # noqa: E501
        """Get stories from a task  # noqa: E501

        Returns the compact records for all stories on the task.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_stories_for_task_with_http_info(task_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str task_gid: The task to operate on. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['task_gid', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_stories_for_task" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'task_gid' is set
        if ('task_gid' not in params or
                params['task_gid'] is None):
            raise ValueError("Missing the required parameter `task_gid` when calling `get_stories_for_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_gid' in params:
            path_params['task_gid'] = params['task_gid']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/tasks/{task_gid}/stories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StoryResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_story(self, story_gid, **kwargs):  # noqa: E501
        """Get a story  # noqa: E501

        Returns the full record for a single story.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_story(story_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str story_gid: Globally unique identifier for the story. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_story_with_http_info(story_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_story_with_http_info(story_gid, **kwargs)  # noqa: E501
            return data

    def get_story_with_http_info(self, story_gid, **kwargs):  # noqa: E501
        """Get a story  # noqa: E501

        Returns the full record for a single story.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_story_with_http_info(story_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str story_gid: Globally unique identifier for the story. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['story_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_story" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'story_gid' is set
        if ('story_gid' not in params or
                params['story_gid'] is None):
            raise ValueError("Missing the required parameter `story_gid` when calling `get_story`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'story_gid' in params:
            path_params['story_gid'] = params['story_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/stories/{story_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StoryResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_story(self, body, story_gid, **kwargs):  # noqa: E501
        """Update a story  # noqa: E501

        Updates the story and returns the full record for the updated story. Only comment stories can have their text updated, and only comment stories and attachment stories can be pinned. Only one of `text` and `html_text` can be specified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_story(body, story_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StoriesStoryGidBody body: The comment story to update. (required)
        :param str story_gid: Globally unique identifier for the story. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_story_with_http_info(body, story_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.update_story_with_http_info(body, story_gid, **kwargs)  # noqa: E501
            return data

    def update_story_with_http_info(self, body, story_gid, **kwargs):  # noqa: E501
        """Update a story  # noqa: E501

        Updates the story and returns the full record for the updated story. Only comment stories can have their text updated, and only comment stories and attachment stories can be pinned. Only one of `text` and `html_text` can be specified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_story_with_http_info(body, story_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StoriesStoryGidBody body: The comment story to update. (required)
        :param str story_gid: Globally unique identifier for the story. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StoryResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'story_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_story" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_story`")  # noqa: E501
        # verify the required parameter 'story_gid' is set
        if ('story_gid' not in params or
                params['story_gid'] is None):
            raise ValueError("Missing the required parameter `story_gid` when calling `update_story`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'story_gid' in params:
            path_params['story_gid'] = params['story_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/stories/{story_gid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StoryResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectTemplateBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'description': 'str',
        'html_description': 'str',
        'public': 'bool',
        'owner': 'AllOfProjectTemplateBaseOwner',
        'team': 'ProjectTemplateBaseTeam',
        'requested_dates': 'list[ProjectTemplateBaseRequestedDates]',
        'color': 'str',
        'requested_roles': 'list[ProjectTemplateBaseRequestedRoles]'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'description': 'description',
        'html_description': 'html_description',
        'public': 'public',
        'owner': 'owner',
        'team': 'team',
        'requested_dates': 'requested_dates',
        'color': 'color',
        'requested_roles': 'requested_roles'
    }

    def __init__(self, gid=None, resource_type=None, name=None, description=None, html_description=None, public=None, owner=None, team=None, requested_dates=None, color=None, requested_roles=None):  # noqa: E501
        """ProjectTemplateBase - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._description = None
        self._html_description = None
        self._public = None
        self._owner = None
        self._team = None
        self._requested_dates = None
        self._color = None
        self._requested_roles = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if html_description is not None:
            self.html_description = html_description
        if public is not None:
            self.public = public
        if owner is not None:
            self.owner = owner
        if team is not None:
            self.team = team
        if requested_dates is not None:
            self.requested_dates = requested_dates
        if color is not None:
            self.color = color
        if requested_roles is not None:
            self.requested_roles = requested_roles

    @property
    def gid(self):
        """Gets the gid of this ProjectTemplateBase.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this ProjectTemplateBase.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this ProjectTemplateBase.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this ProjectTemplateBase.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this ProjectTemplateBase.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this ProjectTemplateBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ProjectTemplateBase.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this ProjectTemplateBase.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this ProjectTemplateBase.  # noqa: E501

        Name of the project template.  # noqa: E501

        :return: The name of this ProjectTemplateBase.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectTemplateBase.

        Name of the project template.  # noqa: E501

        :param name: The name of this ProjectTemplateBase.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ProjectTemplateBase.  # noqa: E501

        Free-form textual information associated with the project template  # noqa: E501

        :return: The description of this ProjectTemplateBase.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProjectTemplateBase.

        Free-form textual information associated with the project template  # noqa: E501

        :param description: The description of this ProjectTemplateBase.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def html_description(self):
        """Gets the html_description of this ProjectTemplateBase.  # noqa: E501

        The description of the project template with formatting as HTML.  # noqa: E501

        :return: The html_description of this ProjectTemplateBase.  # noqa: E501
        :rtype: str
        """
        return self._html_description

    @html_description.setter
    def html_description(self, html_description):
        """Sets the html_description of this ProjectTemplateBase.

        The description of the project template with formatting as HTML.  # noqa: E501

        :param html_description: The html_description of this ProjectTemplateBase.  # noqa: E501
        :type: str
        """

        self._html_description = html_description

    @property
    def public(self):
        """Gets the public of this ProjectTemplateBase.  # noqa: E501

        True if the project template is public to its team.  # noqa: E501

        :return: The public of this ProjectTemplateBase.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ProjectTemplateBase.

        True if the project template is public to its team.  # noqa: E501

        :param public: The public of this ProjectTemplateBase.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def owner(self):
        """Gets the owner of this ProjectTemplateBase.  # noqa: E501

        The current owner of the project template, may be null.  # noqa: E501

        :return: The owner of this ProjectTemplateBase.  # noqa: E501
        :rtype: AllOfProjectTemplateBaseOwner
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this ProjectTemplateBase.

        The current owner of the project template, may be null.  # noqa: E501

        :param owner: The owner of this ProjectTemplateBase.  # noqa: E501
        :type: AllOfProjectTemplateBaseOwner
        """

        self._owner = owner

    @property
    def team(self):
        """Gets the team of this ProjectTemplateBase.  # noqa: E501


        :return: The team of this ProjectTemplateBase.  # noqa: E501
        :rtype: ProjectTemplateBaseTeam
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this ProjectTemplateBase.


        :param team: The team of this ProjectTemplateBase.  # noqa: E501
        :type: ProjectTemplateBaseTeam
        """

        self._team = team

    @property
    def requested_dates(self):
        """Gets the requested_dates of this ProjectTemplateBase.  # noqa: E501

        Array of date variables in this project template. Calendar dates must be provided for these variables when instantiating a project.  # noqa: E501

        :return: The requested_dates of this ProjectTemplateBase.  # noqa: E501
        :rtype: list[ProjectTemplateBaseRequestedDates]
        """
        return self._requested_dates

    @requested_dates.setter
    def requested_dates(self, requested_dates):
        """Sets the requested_dates of this ProjectTemplateBase.

        Array of date variables in this project template. Calendar dates must be provided for these variables when instantiating a project.  # noqa: E501

        :param requested_dates: The requested_dates of this ProjectTemplateBase.  # noqa: E501
        :type: list[ProjectTemplateBaseRequestedDates]
        """

        self._requested_dates = requested_dates

    @property
    def color(self):
        """Gets the color of this ProjectTemplateBase.  # noqa: E501

        Color of the project template.  # noqa: E501

        :return: The color of this ProjectTemplateBase.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this ProjectTemplateBase.

        Color of the project template.  # noqa: E501

        :param color: The color of this ProjectTemplateBase.  # noqa: E501
        :type: str
        """
        allowed_values = ["dark-pink", "dark-green", "dark-blue", "dark-red", "dark-teal", "dark-brown", "dark-orange", "dark-purple", "dark-warm-gray", "light-pink", "light-green", "light-blue", "light-red", "light-teal", "light-brown", "light-orange", "light-purple", "light-warm-gray", ""]  # noqa: E501
        if color not in allowed_values:
            raise ValueError(
                "Invalid value for `color` ({0}), must be one of {1}"  # noqa: E501
                .format(color, allowed_values)
            )

        self._color = color

    @property
    def requested_roles(self):
        """Gets the requested_roles of this ProjectTemplateBase.  # noqa: E501

        Array of template roles in this project template. User Ids can be provided for these variables when instantiating a project to assign template tasks to the user.  # noqa: E501

        :return: The requested_roles of this ProjectTemplateBase.  # noqa: E501
        :rtype: list[ProjectTemplateBaseRequestedRoles]
        """
        return self._requested_roles

    @requested_roles.setter
    def requested_roles(self, requested_roles):
        """Sets the requested_roles of this ProjectTemplateBase.

        Array of template roles in this project template. User Ids can be provided for these variables when instantiating a project to assign template tasks to the user.  # noqa: E501

        :param requested_roles: The requested_roles of this ProjectTemplateBase.  # noqa: E501
        :type: list[ProjectTemplateBaseRequestedRoles]
        """

        self._requested_roles = requested_roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectTemplateBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectTemplateBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.stories_api import StoriesApi  # noqa: E501
from asana.rest import ApiException


class TestStoriesApi(unittest.TestCase):
    """StoriesApi unit test stubs"""

    def setUp(self):
        self.api = StoriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_story_for_task(self):
        """Test case for create_story_for_task

        Create a story on a task  # noqa: E501
        """
        pass

    def test_delete_story(self):
        """Test case for delete_story

        Delete a story  # noqa: E501
        """
        pass

    def test_get_stories_for_task(self):
        """Test case for get_stories_for_task

        Get stories from a task  # noqa: E501
        """
        pass

    def test_get_story(self):
        """Test case for get_story

        Get a story  # noqa: E501
        """
        pass

    def test_update_story(self):
        """Test case for update_story

        Update a story  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'title': 'str',
        'text': 'str',
        'html_text': 'str',
        'color': 'str',
        'author': 'CustomFieldResponsePeopleValue',
        'created_at': 'datetime',
        'created_by': 'CustomFieldResponsePeopleValue',
        'modified_at': 'datetime'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'title': 'title',
        'text': 'text',
        'html_text': 'html_text',
        'color': 'color',
        'author': 'author',
        'created_at': 'created_at',
        'created_by': 'created_by',
        'modified_at': 'modified_at'
    }

    def __init__(self, gid=None, resource_type=None, title=None, text=None, html_text=None, color=None, author=None, created_at=None, created_by=None, modified_at=None):  # noqa: E501
        """ProjectStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._title = None
        self._text = None
        self._html_text = None
        self._color = None
        self._author = None
        self._created_at = None
        self._created_by = None
        self._modified_at = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if title is not None:
            self.title = title
        self.text = text
        if html_text is not None:
            self.html_text = html_text
        self.color = color
        if author is not None:
            self.author = author
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def gid(self):
        """Gets the gid of this ProjectStatusResponse.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this ProjectStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this ProjectStatusResponse.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this ProjectStatusResponse.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this ProjectStatusResponse.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this ProjectStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ProjectStatusResponse.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this ProjectStatusResponse.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def title(self):
        """Gets the title of this ProjectStatusResponse.  # noqa: E501

        The title of the project status update.  # noqa: E501

        :return: The title of this ProjectStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ProjectStatusResponse.

        The title of the project status update.  # noqa: E501

        :param title: The title of this ProjectStatusResponse.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def text(self):
        """Gets the text of this ProjectStatusResponse.  # noqa: E501

        The text content of the status update.  # noqa: E501

        :return: The text of this ProjectStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this ProjectStatusResponse.

        The text content of the status update.  # noqa: E501

        :param text: The text of this ProjectStatusResponse.  # noqa: E501
        :type: str
        """
        if text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def html_text(self):
        """Gets the html_text of this ProjectStatusResponse.  # noqa: E501

        [Opt In](/docs/inputoutput-options). The text content of the status update with formatting as HTML.  # noqa: E501

        :return: The html_text of this ProjectStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._html_text

    @html_text.setter
    def html_text(self, html_text):
        """Sets the html_text of this ProjectStatusResponse.

        [Opt In](/docs/inputoutput-options). The text content of the status update with formatting as HTML.  # noqa: E501

        :param html_text: The html_text of this ProjectStatusResponse.  # noqa: E501
        :type: str
        """

        self._html_text = html_text

    @property
    def color(self):
        """Gets the color of this ProjectStatusResponse.  # noqa: E501

        The color associated with the status update.  # noqa: E501

        :return: The color of this ProjectStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this ProjectStatusResponse.

        The color associated with the status update.  # noqa: E501

        :param color: The color of this ProjectStatusResponse.  # noqa: E501
        :type: str
        """
        if color is None:
            raise ValueError("Invalid value for `color`, must not be `None`")  # noqa: E501
        allowed_values = ["green", "yellow", "red", "blue"]  # noqa: E501
        if color not in allowed_values:
            raise ValueError(
                "Invalid value for `color` ({0}), must be one of {1}"  # noqa: E501
                .format(color, allowed_values)
            )

        self._color = color

    @property
    def author(self):
        """Gets the author of this ProjectStatusResponse.  # noqa: E501


        :return: The author of this ProjectStatusResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this ProjectStatusResponse.


        :param author: The author of this ProjectStatusResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._author = author

    @property
    def created_at(self):
        """Gets the created_at of this ProjectStatusResponse.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this ProjectStatusResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ProjectStatusResponse.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this ProjectStatusResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this ProjectStatusResponse.  # noqa: E501


        :return: The created_by of this ProjectStatusResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ProjectStatusResponse.


        :param created_by: The created_by of this ProjectStatusResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._created_by = created_by

    @property
    def modified_at(self):
        """Gets the modified_at of this ProjectStatusResponse.  # noqa: E501

        The time at which this project status was last modified. *Note: This does not currently reflect any changes in associations such as comments that may have been added or removed from the project status.*  # noqa: E501

        :return: The modified_at of this ProjectStatusResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this ProjectStatusResponse.

        The time at which this project status was last modified. *Note: This does not currently reflect any changes in associations such as comments that may have been added or removed from the project status.*  # noqa: E501

        :param modified_at: The modified_at of this ProjectStatusResponse.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class WorkspaceMembershipsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_workspace_membership(self, workspace_membership_gid, **kwargs):  # noqa: E501
        """Get a workspace membership  # noqa: E501

        Returns the complete workspace record for a single workspace membership.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_membership(workspace_membership_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_membership_gid: (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: WorkspaceMembershipResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workspace_membership_with_http_info(workspace_membership_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workspace_membership_with_http_info(workspace_membership_gid, **kwargs)  # noqa: E501
            return data

    def get_workspace_membership_with_http_info(self, workspace_membership_gid, **kwargs):  # noqa: E501
        """Get a workspace membership  # noqa: E501

        Returns the complete workspace record for a single workspace membership.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_membership_with_http_info(workspace_membership_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_membership_gid: (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: WorkspaceMembershipResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_membership_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workspace_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_membership_gid' is set
        if ('workspace_membership_gid' not in params or
                params['workspace_membership_gid'] is None):
            raise ValueError("Missing the required parameter `workspace_membership_gid` when calling `get_workspace_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_membership_gid' in params:
            path_params['workspace_membership_gid'] = params['workspace_membership_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/workspace_memberships/{workspace_membership_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkspaceMembershipResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workspace_memberships_for_user(self, user_gid, **kwargs):  # noqa: E501
        """Get workspace memberships for a user  # noqa: E501

        Returns the compact workspace membership records for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_memberships_for_user(user_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_gid: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: WorkspaceMembershipResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workspace_memberships_for_user_with_http_info(user_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workspace_memberships_for_user_with_http_info(user_gid, **kwargs)  # noqa: E501
            return data

    def get_workspace_memberships_for_user_with_http_info(self, user_gid, **kwargs):  # noqa: E501
        """Get workspace memberships for a user  # noqa: E501

        Returns the compact workspace membership records for the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_memberships_for_user_with_http_info(user_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_gid: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: WorkspaceMembershipResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_gid', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workspace_memberships_for_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_gid' is set
        if ('user_gid' not in params or
                params['user_gid'] is None):
            raise ValueError("Missing the required parameter `user_gid` when calling `get_workspace_memberships_for_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_gid' in params:
            path_params['user_gid'] = params['user_gid']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_gid}/workspace_memberships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkspaceMembershipResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workspace_memberships_for_workspace(self, workspace_gid, **kwargs):  # noqa: E501
        """Get the workspace memberships for a workspace  # noqa: E501

        Returns the compact workspace membership records for the workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_memberships_for_workspace(workspace_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_gid: Globally unique identifier for the workspace or organization. (required)
        :param str user: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user.
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: WorkspaceMembershipResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workspace_memberships_for_workspace_with_http_info(workspace_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workspace_memberships_for_workspace_with_http_info(workspace_gid, **kwargs)  # noqa: E501
            return data

    def get_workspace_memberships_for_workspace_with_http_info(self, workspace_gid, **kwargs):  # noqa: E501
        """Get the workspace memberships for a workspace  # noqa: E501

        Returns the compact workspace membership records for the workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_memberships_for_workspace_with_http_info(workspace_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_gid: Globally unique identifier for the workspace or organization. (required)
        :param str user: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user.
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: WorkspaceMembershipResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_gid', 'user', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workspace_memberships_for_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_gid' is set
        if ('workspace_gid' not in params or
                params['workspace_gid'] is None):
            raise ValueError("Missing the required parameter `workspace_gid` when calling `get_workspace_memberships_for_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_gid' in params:
            path_params['workspace_gid'] = params['workspace_gid']  # noqa: E501

        query_params = []
        if 'user' in params:
            query_params.append(('user', params['user']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/workspaces/{workspace_gid}/workspace_memberships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkspaceMembershipResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.custom_fields_api import CustomFieldsApi  # noqa: E501
from asana.rest import ApiException


class TestCustomFieldsApi(unittest.TestCase):
    """CustomFieldsApi unit test stubs"""

    def setUp(self):
        self.api = CustomFieldsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_custom_field(self):
        """Test case for create_custom_field

        Create a custom field  # noqa: E501
        """
        pass

    def test_create_enum_option_for_custom_field(self):
        """Test case for create_enum_option_for_custom_field

        Create an enum option  # noqa: E501
        """
        pass

    def test_delete_custom_field(self):
        """Test case for delete_custom_field

        Delete a custom field  # noqa: E501
        """
        pass

    def test_get_custom_field(self):
        """Test case for get_custom_field

        Get a custom field  # noqa: E501
        """
        pass

    def test_get_custom_fields_for_workspace(self):
        """Test case for get_custom_fields_for_workspace

        Get a workspace's custom fields  # noqa: E501
        """
        pass

    def test_insert_enum_option_for_custom_field(self):
        """Test case for insert_enum_option_for_custom_field

        Reorder a custom field's enum  # noqa: E501
        """
        pass

    def test_update_custom_field(self):
        """Test case for update_custom_field

        Update a custom field  # noqa: E501
        """
        pass

    def test_update_enum_option(self):
        """Test case for update_enum_option

        Update an enum option  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class AttachmentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_attachment_for_object(self, **kwargs):  # noqa: E501
        """Upload an attachment  # noqa: E501

        Upload an attachment.  This method uploads an attachment on an object and returns the compact record for the created attachment object. This is possible by either:  - Providing the URL of the external resource being attached, or - Downloading the file content first and then uploading it as any other attachment. Note that it is not possible to attach files from third party services such as Dropbox, Box, Vimeo & Google Drive via the API  The 100MB size limit on attachments in Asana is enforced on this endpoint.  This endpoint expects a multipart/form-data encoded request containing the full contents of the file to be uploaded.  Requests made should follow the HTTP/1.1 specification that line terminators are of the form `CRLF` or `\\r\\n` outlined [here](http://www.w3.org/Protocols/HTTP/1.1/draft-ietf-http-v11-spec-01#Basic-Rules) in order for the server to reliably and properly handle the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_attachment_for_object(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resource_subtype:
        :param str file:
        :param str parent:
        :param str url:
        :param str name:
        :param bool connect_to_app:
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AttachmentResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_attachment_for_object_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_attachment_for_object_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_attachment_for_object_with_http_info(self, **kwargs):  # noqa: E501
        """Upload an attachment  # noqa: E501

        Upload an attachment.  This method uploads an attachment on an object and returns the compact record for the created attachment object. This is possible by either:  - Providing the URL of the external resource being attached, or - Downloading the file content first and then uploading it as any other attachment. Note that it is not possible to attach files from third party services such as Dropbox, Box, Vimeo & Google Drive via the API  The 100MB size limit on attachments in Asana is enforced on this endpoint.  This endpoint expects a multipart/form-data encoded request containing the full contents of the file to be uploaded.  Requests made should follow the HTTP/1.1 specification that line terminators are of the form `CRLF` or `\\r\\n` outlined [here](http://www.w3.org/Protocols/HTTP/1.1/draft-ietf-http-v11-spec-01#Basic-Rules) in order for the server to reliably and properly handle the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_attachment_for_object_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resource_subtype:
        :param str file:
        :param str parent:
        :param str url:
        :param str name:
        :param bool connect_to_app:
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AttachmentResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource_subtype', 'file', 'parent', 'url', 'name', 'connect_to_app', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_attachment_for_object" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'resource_subtype' in params:
            form_params.append(('resource_subtype', params['resource_subtype']))  # noqa: E501
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501
        if 'parent' in params:
            form_params.append(('parent', params['parent']))  # noqa: E501
        if 'url' in params:
            form_params.append(('url', params['url']))  # noqa: E501
        if 'name' in params:
            form_params.append(('name', params['name']))  # noqa: E501
        if 'connect_to_app' in params:
            form_params.append(('connect_to_app', params['connect_to_app']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/attachments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_attachment(self, attachment_gid, **kwargs):  # noqa: E501
        """Delete an attachment  # noqa: E501

        Deletes a specific, existing attachment.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_attachment(attachment_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attachment_gid: Globally unique identifier for the attachment. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_attachment_with_http_info(attachment_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_attachment_with_http_info(attachment_gid, **kwargs)  # noqa: E501
            return data

    def delete_attachment_with_http_info(self, attachment_gid, **kwargs):  # noqa: E501
        """Delete an attachment  # noqa: E501

        Deletes a specific, existing attachment.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_attachment_with_http_info(attachment_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attachment_gid: Globally unique identifier for the attachment. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attachment_gid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_attachment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attachment_gid' is set
        if ('attachment_gid' not in params or
                params['attachment_gid'] is None):
            raise ValueError("Missing the required parameter `attachment_gid` when calling `delete_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_gid' in params:
            path_params['attachment_gid'] = params['attachment_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/attachments/{attachment_gid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment(self, attachment_gid, **kwargs):  # noqa: E501
        """Get an attachment  # noqa: E501

        Get the full record for a single attachment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment(attachment_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attachment_gid: Globally unique identifier for the attachment. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AttachmentResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachment_with_http_info(attachment_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attachment_with_http_info(attachment_gid, **kwargs)  # noqa: E501
            return data

    def get_attachment_with_http_info(self, attachment_gid, **kwargs):  # noqa: E501
        """Get an attachment  # noqa: E501

        Get the full record for a single attachment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_with_http_info(attachment_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attachment_gid: Globally unique identifier for the attachment. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AttachmentResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attachment_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attachment_gid' is set
        if ('attachment_gid' not in params or
                params['attachment_gid'] is None):
            raise ValueError("Missing the required parameter `attachment_gid` when calling `get_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_gid' in params:
            path_params['attachment_gid'] = params['attachment_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/attachments/{attachment_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachments_for_object(self, parent, **kwargs):  # noqa: E501
        """Get attachments from an object  # noqa: E501

        Returns the compact records for all attachments on the object.  There are three possible `parent` values for this request: `project`, `project_brief`, and `task`. For a project, an attachment refers to a file uploaded to the \"Key resources\" section in the project Overview. For a project brief, an attachment refers to inline files in the project brief itself. For a task, an attachment refers to a file directly associated to that task.  Note that within the Asana app, inline images in the task description do not appear in the index of image thumbnails nor as stories in the task. However, requests made to `GET /attachments` for a task will return all of the images in the task, including inline images.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachments_for_object(parent, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parent: Globally unique identifier for object to fetch statuses from. Must be a GID for a `project`, `project_brief`, or `task`. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AttachmentResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attachments_for_object_with_http_info(parent, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attachments_for_object_with_http_info(parent, **kwargs)  # noqa: E501
            return data

    def get_attachments_for_object_with_http_info(self, parent, **kwargs):  # noqa: E501
        """Get attachments from an object  # noqa: E501

        Returns the compact records for all attachments on the object.  There are three possible `parent` values for this request: `project`, `project_brief`, and `task`. For a project, an attachment refers to a file uploaded to the \"Key resources\" section in the project Overview. For a project brief, an attachment refers to inline files in the project brief itself. For a task, an attachment refers to a file directly associated to that task.  Note that within the Asana app, inline images in the task description do not appear in the index of image thumbnails nor as stories in the task. However, requests made to `GET /attachments` for a task will return all of the images in the task, including inline images.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachments_for_object_with_http_info(parent, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parent: Globally unique identifier for object to fetch statuses from. Must be a GID for a `project`, `project_brief`, or `task`. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AttachmentResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['parent', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachments_for_object" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'parent' is set
        if ('parent' not in params or
                params['parent'] is None):
            raise ValueError("Missing the required parameter `parent` when calling `get_attachments_for_object`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'parent' in params:
            query_params.append(('parent', params['parent']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/attachments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource': 'str',
        'target': 'str',
        'filters': 'list[WebhookRequestFilters]'
    }

    attribute_map = {
        'resource': 'resource',
        'target': 'target',
        'filters': 'filters'
    }

    def __init__(self, resource=None, target=None, filters=None):  # noqa: E501
        """WebhookRequest - a model defined in Swagger"""  # noqa: E501
        self._resource = None
        self._target = None
        self._filters = None
        self.discriminator = None
        self.resource = resource
        self.target = target
        if filters is not None:
            self.filters = filters

    @property
    def resource(self):
        """Gets the resource of this WebhookRequest.  # noqa: E501

        A resource ID to subscribe to. Many Asana resources are valid to create webhooks on, but higher-level resources require filters.  # noqa: E501

        :return: The resource of this WebhookRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this WebhookRequest.

        A resource ID to subscribe to. Many Asana resources are valid to create webhooks on, but higher-level resources require filters.  # noqa: E501

        :param resource: The resource of this WebhookRequest.  # noqa: E501
        :type: str
        """
        if resource is None:
            raise ValueError("Invalid value for `resource`, must not be `None`")  # noqa: E501

        self._resource = resource

    @property
    def target(self):
        """Gets the target of this WebhookRequest.  # noqa: E501

        The URL to receive the HTTP POST. The full URL will be used to deliver events from this webhook (including parameters) which allows encoding of application-specific state when the webhook is created.  # noqa: E501

        :return: The target of this WebhookRequest.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this WebhookRequest.

        The URL to receive the HTTP POST. The full URL will be used to deliver events from this webhook (including parameters) which allows encoding of application-specific state when the webhook is created.  # noqa: E501

        :param target: The target of this WebhookRequest.  # noqa: E501
        :type: str
        """
        if target is None:
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    @property
    def filters(self):
        """Gets the filters of this WebhookRequest.  # noqa: E501

        An array of WebhookFilter objects to specify a whitelist of filters to apply to events from this webhook. If a webhook event passes any of the filters the event will be delivered; otherwise no event will be sent to the receiving server.  # noqa: E501

        :return: The filters of this WebhookRequest.  # noqa: E501
        :rtype: list[WebhookRequestFilters]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this WebhookRequest.

        An array of WebhookFilter objects to specify a whitelist of filters to apply to events from this webhook. If a webhook event passes any of the filters the event will be delivered; otherwise no event will be sent to the receiving server.  # noqa: E501

        :param filters: The filters of this WebhookRequest.  # noqa: E501
        :type: list[WebhookRequestFilters]
        """

        self._filters = filters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class JobBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'resource_subtype': 'str',
        'status': 'str',
        'new_project': 'JobBaseNewProject',
        'new_task': 'JobBaseNewTask',
        'new_project_template': 'JobBaseNewProjectTemplate'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'resource_subtype': 'resource_subtype',
        'status': 'status',
        'new_project': 'new_project',
        'new_task': 'new_task',
        'new_project_template': 'new_project_template'
    }

    def __init__(self, gid=None, resource_type=None, resource_subtype=None, status=None, new_project=None, new_task=None, new_project_template=None):  # noqa: E501
        """JobBase - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._resource_subtype = None
        self._status = None
        self._new_project = None
        self._new_task = None
        self._new_project_template = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if status is not None:
            self.status = status
        if new_project is not None:
            self.new_project = new_project
        if new_task is not None:
            self.new_task = new_task
        if new_project_template is not None:
            self.new_project_template = new_project_template

    @property
    def gid(self):
        """Gets the gid of this JobBase.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this JobBase.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this JobBase.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this JobBase.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this JobBase.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this JobBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this JobBase.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this JobBase.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this JobBase.  # noqa: E501

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.  # noqa: E501

        :return: The resource_subtype of this JobBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this JobBase.

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.  # noqa: E501

        :param resource_subtype: The resource_subtype of this JobBase.  # noqa: E501
        :type: str
        """

        self._resource_subtype = resource_subtype

    @property
    def status(self):
        """Gets the status of this JobBase.  # noqa: E501

        The current status of this job. The value is one of: `not_started`, `in_progress`, `succeeded`, or `failed`.  # noqa: E501

        :return: The status of this JobBase.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobBase.

        The current status of this job. The value is one of: `not_started`, `in_progress`, `succeeded`, or `failed`.  # noqa: E501

        :param status: The status of this JobBase.  # noqa: E501
        :type: str
        """
        allowed_values = ["not_started", "in_progress", "succeeded", "failed"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def new_project(self):
        """Gets the new_project of this JobBase.  # noqa: E501


        :return: The new_project of this JobBase.  # noqa: E501
        :rtype: JobBaseNewProject
        """
        return self._new_project

    @new_project.setter
    def new_project(self, new_project):
        """Sets the new_project of this JobBase.


        :param new_project: The new_project of this JobBase.  # noqa: E501
        :type: JobBaseNewProject
        """

        self._new_project = new_project

    @property
    def new_task(self):
        """Gets the new_task of this JobBase.  # noqa: E501


        :return: The new_task of this JobBase.  # noqa: E501
        :rtype: JobBaseNewTask
        """
        return self._new_task

    @new_task.setter
    def new_task(self, new_task):
        """Sets the new_task of this JobBase.


        :param new_task: The new_task of this JobBase.  # noqa: E501
        :type: JobBaseNewTask
        """

        self._new_task = new_task

    @property
    def new_project_template(self):
        """Gets the new_project_template of this JobBase.  # noqa: E501


        :return: The new_project_template of this JobBase.  # noqa: E501
        :rtype: JobBaseNewProjectTemplate
        """
        return self._new_project_template

    @new_project_template.setter
    def new_project_template(self, new_project_template):
        """Sets the new_project_template of this JobBase.


        :param new_project_template: The new_project_template of this JobBase.  # noqa: E501
        :type: JobBaseNewProjectTemplate
        """

        self._new_project_template = new_project_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.workspace_memberships_api import WorkspaceMembershipsApi  # noqa: E501
from asana.rest import ApiException


class TestWorkspaceMembershipsApi(unittest.TestCase):
    """WorkspaceMembershipsApi unit test stubs"""

    def setUp(self):
        self.api = WorkspaceMembershipsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_workspace_membership(self):
        """Test case for get_workspace_membership

        Get a workspace membership  # noqa: E501
        """
        pass

    def test_get_workspace_memberships_for_user(self):
        """Test case for get_workspace_memberships_for_user

        Get workspace memberships for a user  # noqa: E501
        """
        pass

    def test_get_workspace_memberships_for_workspace(self):
        """Test case for get_workspace_memberships_for_workspace

        Get the workspace memberships for a workspace  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventResponseChange(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field': 'str',
        'action': 'str',
        'new_value': 'object',
        'added_value': 'object',
        'removed_value': 'object'
    }

    attribute_map = {
        'field': 'field',
        'action': 'action',
        'new_value': 'new_value',
        'added_value': 'added_value',
        'removed_value': 'removed_value'
    }

    def __init__(self, field=None, action=None, new_value=None, added_value=None, removed_value=None):  # noqa: E501
        """EventResponseChange - a model defined in Swagger"""  # noqa: E501
        self._field = None
        self._action = None
        self._new_value = None
        self._added_value = None
        self._removed_value = None
        self.discriminator = None
        if field is not None:
            self.field = field
        if action is not None:
            self.action = action
        if new_value is not None:
            self.new_value = new_value
        if added_value is not None:
            self.added_value = added_value
        if removed_value is not None:
            self.removed_value = removed_value

    @property
    def field(self):
        """Gets the field of this EventResponseChange.  # noqa: E501

        The name of the field that has changed in the resource.  # noqa: E501

        :return: The field of this EventResponseChange.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this EventResponseChange.

        The name of the field that has changed in the resource.  # noqa: E501

        :param field: The field of this EventResponseChange.  # noqa: E501
        :type: str
        """

        self._field = field

    @property
    def action(self):
        """Gets the action of this EventResponseChange.  # noqa: E501

        The type of action taken on the **field** which has been changed.  This can be one of `changed`, `added`, or `removed` depending on the nature of the change.  # noqa: E501

        :return: The action of this EventResponseChange.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this EventResponseChange.

        The type of action taken on the **field** which has been changed.  This can be one of `changed`, `added`, or `removed` depending on the nature of the change.  # noqa: E501

        :param action: The action of this EventResponseChange.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def new_value(self):
        """Gets the new_value of this EventResponseChange.  # noqa: E501

        *Conditional.* This property is only present when the value of the event's `change.action` is `changed` _and_ the `new_value` is an Asana resource. This will be only the `gid` and `resource_type` of the resource when the events come from webhooks; this will be the compact representation (and can have fields expanded with [opt_fields](/docs/inputoutput-options)) when using the [get events](/reference/getevents) endpoint.  # noqa: E501

        :return: The new_value of this EventResponseChange.  # noqa: E501
        :rtype: object
        """
        return self._new_value

    @new_value.setter
    def new_value(self, new_value):
        """Sets the new_value of this EventResponseChange.

        *Conditional.* This property is only present when the value of the event's `change.action` is `changed` _and_ the `new_value` is an Asana resource. This will be only the `gid` and `resource_type` of the resource when the events come from webhooks; this will be the compact representation (and can have fields expanded with [opt_fields](/docs/inputoutput-options)) when using the [get events](/reference/getevents) endpoint.  # noqa: E501

        :param new_value: The new_value of this EventResponseChange.  # noqa: E501
        :type: object
        """

        self._new_value = new_value

    @property
    def added_value(self):
        """Gets the added_value of this EventResponseChange.  # noqa: E501

        *Conditional.* This property is only present when the value of the event's `change.action` is `added` _and_ the `added_value` is an Asana resource. This will be only the `gid` and `resource_type` of the resource when the events come from webhooks; this will be the compact representation (and can have fields expanded with [opt_fields](/docs/inputoutput-options)) when using the [get events](/reference/getevents) endpoint.  # noqa: E501

        :return: The added_value of this EventResponseChange.  # noqa: E501
        :rtype: object
        """
        return self._added_value

    @added_value.setter
    def added_value(self, added_value):
        """Sets the added_value of this EventResponseChange.

        *Conditional.* This property is only present when the value of the event's `change.action` is `added` _and_ the `added_value` is an Asana resource. This will be only the `gid` and `resource_type` of the resource when the events come from webhooks; this will be the compact representation (and can have fields expanded with [opt_fields](/docs/inputoutput-options)) when using the [get events](/reference/getevents) endpoint.  # noqa: E501

        :param added_value: The added_value of this EventResponseChange.  # noqa: E501
        :type: object
        """

        self._added_value = added_value

    @property
    def removed_value(self):
        """Gets the removed_value of this EventResponseChange.  # noqa: E501

        *Conditional.* This property is only present when the value of the event's `change.action` is `removed` _and_ the `removed_value` is an Asana resource. This will be only the `gid` and `resource_type` of the resource when the events come from webhooks; this will be the compact representation (and can have fields expanded with [opt_fields](/docs/inputoutput-options)) when using the [get events](/reference/getevents) endpoint.  # noqa: E501

        :return: The removed_value of this EventResponseChange.  # noqa: E501
        :rtype: object
        """
        return self._removed_value

    @removed_value.setter
    def removed_value(self, removed_value):
        """Sets the removed_value of this EventResponseChange.

        *Conditional.* This property is only present when the value of the event's `change.action` is `removed` _and_ the `removed_value` is an Asana resource. This will be only the `gid` and `resource_type` of the resource when the events come from webhooks; this will be the compact representation (and can have fields expanded with [opt_fields](/docs/inputoutput-options)) when using the [get events](/reference/getevents) endpoint.  # noqa: E501

        :param removed_value: The removed_value of this EventResponseChange.  # noqa: E501
        :type: object
        """

        self._removed_value = removed_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventResponseChange, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventResponseChange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from asana.models.add_custom_field_setting_request import AddCustomFieldSettingRequest
from asana.models.add_followers_request import AddFollowersRequest
from asana.models.add_members_request import AddMembersRequest
from asana.models.all_of_project_response_owner import AllOfProjectResponseOwner
from asana.models.all_of_project_template_base_owner import AllOfProjectTemplateBaseOwner
from asana.models.all_of_project_template_response_owner import AllOfProjectTemplateResponseOwner
from asana.models.all_of_story_response_new_date_value import AllOfStoryResponseNewDateValue
from asana.models.all_of_story_response_old_date_value import AllOfStoryResponseOldDateValue
from asana.models.all_of_user_task_list_base_owner import AllOfUserTaskListBaseOwner
from asana.models.all_of_user_task_list_base_workspace import AllOfUserTaskListBaseWorkspace
from asana.models.all_of_user_task_list_compact_owner import AllOfUserTaskListCompactOwner
from asana.models.all_of_user_task_list_compact_workspace import AllOfUserTaskListCompactWorkspace
from asana.models.all_of_user_task_list_request_owner import AllOfUserTaskListRequestOwner
from asana.models.all_of_user_task_list_request_workspace import AllOfUserTaskListRequestWorkspace
from asana.models.all_of_user_task_list_response_owner import AllOfUserTaskListResponseOwner
from asana.models.all_of_user_task_list_response_workspace import AllOfUserTaskListResponseWorkspace
from asana.models.all_of_workspace_membership_response_user_task_list_owner import AllOfWorkspaceMembershipResponseUserTaskListOwner
from asana.models.all_of_workspace_membership_response_user_task_list_workspace import AllOfWorkspaceMembershipResponseUserTaskListWorkspace
from asana.models.asana_named_resource import AsanaNamedResource
from asana.models.asana_named_resource_array import AsanaNamedResourceArray
from asana.models.asana_resource import AsanaResource
from asana.models.attachment_base import AttachmentBase
from asana.models.attachment_compact import AttachmentCompact
from asana.models.attachment_request import AttachmentRequest
from asana.models.attachment_response import AttachmentResponse
from asana.models.attachment_response_array import AttachmentResponseArray
from asana.models.attachment_response_data import AttachmentResponseData
from asana.models.attachment_response_parent import AttachmentResponseParent
from asana.models.audit_log_event import AuditLogEvent
from asana.models.audit_log_event_actor import AuditLogEventActor
from asana.models.audit_log_event_array import AuditLogEventArray
from asana.models.audit_log_event_context import AuditLogEventContext
from asana.models.audit_log_event_details import AuditLogEventDetails
from asana.models.audit_log_event_resource import AuditLogEventResource
from asana.models.batch_body import BatchBody
from asana.models.batch_request import BatchRequest
from asana.models.batch_request_action import BatchRequestAction
from asana.models.batch_request_actions import BatchRequestActions
from asana.models.batch_request_options import BatchRequestOptions
from asana.models.batch_response import BatchResponse
from asana.models.batch_response_array import BatchResponseArray
from asana.models.create_membership_request import CreateMembershipRequest
from asana.models.create_time_tracking_entry_request import CreateTimeTrackingEntryRequest
from asana.models.custom_field_base import CustomFieldBase
from asana.models.custom_field_base_date_value import CustomFieldBaseDateValue
from asana.models.custom_field_base_enum_options import CustomFieldBaseEnumOptions
from asana.models.custom_field_base_enum_value import CustomFieldBaseEnumValue
from asana.models.custom_field_compact import CustomFieldCompact
from asana.models.custom_field_gid_enum_options_body import CustomFieldGidEnumOptionsBody
from asana.models.custom_field_request import CustomFieldRequest
from asana.models.custom_field_response import CustomFieldResponse
from asana.models.custom_field_response_array import CustomFieldResponseArray
from asana.models.custom_field_response_created_by import CustomFieldResponseCreatedBy
from asana.models.custom_field_response_data import CustomFieldResponseData
from asana.models.custom_field_response_people_value import CustomFieldResponsePeopleValue
from asana.models.custom_field_setting_base import CustomFieldSettingBase
from asana.models.custom_field_setting_compact import CustomFieldSettingCompact
from asana.models.custom_field_setting_response import CustomFieldSettingResponse
from asana.models.custom_field_setting_response_array import CustomFieldSettingResponseArray
from asana.models.custom_field_setting_response_custom_field import CustomFieldSettingResponseCustomField
from asana.models.custom_field_setting_response_data import CustomFieldSettingResponseData
from asana.models.custom_field_setting_response_parent import CustomFieldSettingResponseParent
from asana.models.custom_field_setting_response_project import CustomFieldSettingResponseProject
from asana.models.custom_fields_body import CustomFieldsBody
from asana.models.custom_fields_custom_field_gid_body import CustomFieldsCustomFieldGidBody
from asana.models.date_variable_compact import DateVariableCompact
from asana.models.date_variable_request import DateVariableRequest
from asana.models.empty_response import EmptyResponse
from asana.models.empty_response_data import EmptyResponseData
from asana.models.enum_option import EnumOption
from asana.models.enum_option_base import EnumOptionBase
from asana.models.enum_option_data import EnumOptionData
from asana.models.enum_option_insert_request import EnumOptionInsertRequest
from asana.models.enum_option_request import EnumOptionRequest
from asana.models.enum_options_enum_option_gid_body import EnumOptionsEnumOptionGidBody
from asana.models.enum_options_insert_body import EnumOptionsInsertBody
from asana.models.error import Error
from asana.models.error_response import ErrorResponse
from asana.models.error_response_errors import ErrorResponseErrors
from asana.models.event_response import EventResponse
from asana.models.event_response_array import EventResponseArray
from asana.models.event_response_change import EventResponseChange
from asana.models.event_response_parent import EventResponseParent
from asana.models.event_response_resource import EventResponseResource
from asana.models.event_response_user import EventResponseUser
from asana.models.goal_add_subgoal_request import GoalAddSubgoalRequest
from asana.models.goal_add_supporting_relationship_request import GoalAddSupportingRelationshipRequest
from asana.models.goal_add_supporting_work_request import GoalAddSupportingWorkRequest
from asana.models.goal_base import GoalBase
from asana.models.goal_compact import GoalCompact
from asana.models.goal_gid_add_followers_body import GoalGidAddFollowersBody
from asana.models.goal_gid_add_supporting_relationship_body import GoalGidAddSupportingRelationshipBody
from asana.models.goal_gid_remove_followers_body import GoalGidRemoveFollowersBody
from asana.models.goal_gid_remove_supporting_relationship_body import GoalGidRemoveSupportingRelationshipBody
from asana.models.goal_gid_set_metric_body import GoalGidSetMetricBody
from asana.models.goal_gid_set_metric_current_value_body import GoalGidSetMetricCurrentValueBody
from asana.models.goal_membership_base import GoalMembershipBase
from asana.models.goal_membership_compact import GoalMembershipCompact
from asana.models.goal_membership_response import GoalMembershipResponse
from asana.models.goal_membership_response_user import GoalMembershipResponseUser
from asana.models.goal_membership_response_workspace import GoalMembershipResponseWorkspace
from asana.models.goal_metric_base import GoalMetricBase
from asana.models.goal_metric_current_value_request import GoalMetricCurrentValueRequest
from asana.models.goal_metric_request import GoalMetricRequest
from asana.models.goal_relationship_base import GoalRelationshipBase
from asana.models.goal_relationship_base_supported_goal import GoalRelationshipBaseSupportedGoal
from asana.models.goal_relationship_base_supporting_resource import GoalRelationshipBaseSupportingResource
from asana.models.goal_relationship_compact import GoalRelationshipCompact
from asana.models.goal_relationship_request import GoalRelationshipRequest
from asana.models.goal_relationship_response import GoalRelationshipResponse
from asana.models.goal_relationship_response_array import GoalRelationshipResponseArray
from asana.models.goal_relationship_response_data import GoalRelationshipResponseData
from asana.models.goal_relationships_goal_relationship_gid_body import GoalRelationshipsGoalRelationshipGidBody
from asana.models.goal_remove_subgoal_request import GoalRemoveSubgoalRequest
from asana.models.goal_remove_supporting_relationship_request import GoalRemoveSupportingRelationshipRequest
from asana.models.goal_request import GoalRequest
from asana.models.goal_request_base import GoalRequestBase
from asana.models.goal_response import GoalResponse
from asana.models.goal_response_array import GoalResponseArray
from asana.models.goal_response_current_status_update import GoalResponseCurrentStatusUpdate
from asana.models.goal_response_data import GoalResponseData
from asana.models.goal_response_likes import GoalResponseLikes
from asana.models.goal_response_metric import GoalResponseMetric
from asana.models.goal_response_team import GoalResponseTeam
from asana.models.goal_response_time_period import GoalResponseTimePeriod
from asana.models.goal_response_workspace import GoalResponseWorkspace
from asana.models.goal_update_request import GoalUpdateRequest
from asana.models.goals_body import GoalsBody
from asana.models.goals_goal_gid_body import GoalsGoalGidBody
from asana.models.inline_response412 import InlineResponse412
from asana.models.inline_response412_errors import InlineResponse412Errors
from asana.models.job_base import JobBase
from asana.models.job_base_new_project import JobBaseNewProject
from asana.models.job_base_new_project_template import JobBaseNewProjectTemplate
from asana.models.job_base_new_task import JobBaseNewTask
from asana.models.job_compact import JobCompact
from asana.models.job_response import JobResponse
from asana.models.job_response_data import JobResponseData
from asana.models.like import Like
from asana.models.member_compact import MemberCompact
from asana.models.membership_compact import MembershipCompact
from asana.models.membership_compact_goal import MembershipCompactGoal
from asana.models.membership_compact_member import MembershipCompactMember
from asana.models.membership_compact_parent import MembershipCompactParent
from asana.models.membership_request import MembershipRequest
from asana.models.membership_response import MembershipResponse
from asana.models.membership_response_array import MembershipResponseArray
from asana.models.membership_response_data import MembershipResponseData
from asana.models.memberships_body import MembershipsBody
from asana.models.modify_dependencies_request import ModifyDependenciesRequest
from asana.models.modify_dependents_request import ModifyDependentsRequest
from asana.models.next_page import NextPage
from asana.models.organization_export_base import OrganizationExportBase
from asana.models.organization_export_compact import OrganizationExportCompact
from asana.models.organization_export_request import OrganizationExportRequest
from asana.models.organization_export_response import OrganizationExportResponse
from asana.models.organization_export_response_data import OrganizationExportResponseData
from asana.models.organization_exports_body import OrganizationExportsBody
from asana.models.portfolio_add_item_request import PortfolioAddItemRequest
from asana.models.portfolio_base import PortfolioBase
from asana.models.portfolio_compact import PortfolioCompact
from asana.models.portfolio_gid_add_custom_field_setting_body import PortfolioGidAddCustomFieldSettingBody
from asana.models.portfolio_gid_add_item_body import PortfolioGidAddItemBody
from asana.models.portfolio_gid_add_members_body import PortfolioGidAddMembersBody
from asana.models.portfolio_gid_remove_custom_field_setting_body import PortfolioGidRemoveCustomFieldSettingBody
from asana.models.portfolio_gid_remove_item_body import PortfolioGidRemoveItemBody
from asana.models.portfolio_gid_remove_members_body import PortfolioGidRemoveMembersBody
from asana.models.portfolio_membership_base import PortfolioMembershipBase
from asana.models.portfolio_membership_base_portfolio import PortfolioMembershipBasePortfolio
from asana.models.portfolio_membership_compact import PortfolioMembershipCompact
from asana.models.portfolio_membership_response import PortfolioMembershipResponse
from asana.models.portfolio_membership_response_array import PortfolioMembershipResponseArray
from asana.models.portfolio_membership_response_data import PortfolioMembershipResponseData
from asana.models.portfolio_remove_item_request import PortfolioRemoveItemRequest
from asana.models.portfolio_request import PortfolioRequest
from asana.models.portfolio_response import PortfolioResponse
from asana.models.portfolio_response_array import PortfolioResponseArray
from asana.models.portfolio_response_current_status_update import PortfolioResponseCurrentStatusUpdate
from asana.models.portfolio_response_custom_field_settings import PortfolioResponseCustomFieldSettings
from asana.models.portfolio_response_custom_fields import PortfolioResponseCustomFields
from asana.models.portfolio_response_data import PortfolioResponseData
from asana.models.portfolio_response_workspace import PortfolioResponseWorkspace
from asana.models.portfolios_body import PortfoliosBody
from asana.models.portfolios_portfolio_gid_body import PortfoliosPortfolioGidBody
from asana.models.preview import Preview
from asana.models.project_base import ProjectBase
from asana.models.project_base_current_status import ProjectBaseCurrentStatus
from asana.models.project_base_current_status_update import ProjectBaseCurrentStatusUpdate
from asana.models.project_brief_base import ProjectBriefBase
from asana.models.project_brief_compact import ProjectBriefCompact
from asana.models.project_brief_request import ProjectBriefRequest
from asana.models.project_brief_response import ProjectBriefResponse
from asana.models.project_brief_response_data import ProjectBriefResponseData
from asana.models.project_brief_response_project import ProjectBriefResponseProject
from asana.models.project_briefs_project_brief_gid_body import ProjectBriefsProjectBriefGidBody
from asana.models.project_compact import ProjectCompact
from asana.models.project_duplicate_request import ProjectDuplicateRequest
from asana.models.project_duplicate_request_schedule_dates import ProjectDuplicateRequestScheduleDates
from asana.models.project_gid_add_custom_field_setting_body import ProjectGidAddCustomFieldSettingBody
from asana.models.project_gid_add_followers_body import ProjectGidAddFollowersBody
from asana.models.project_gid_add_members_body import ProjectGidAddMembersBody
from asana.models.project_gid_duplicate_body import ProjectGidDuplicateBody
from asana.models.project_gid_project_briefs_body import ProjectGidProjectBriefsBody
from asana.models.project_gid_project_statuses_body import ProjectGidProjectStatusesBody
from asana.models.project_gid_remove_custom_field_setting_body import ProjectGidRemoveCustomFieldSettingBody
from asana.models.project_gid_remove_followers_body import ProjectGidRemoveFollowersBody
from asana.models.project_gid_remove_members_body import ProjectGidRemoveMembersBody
from asana.models.project_gid_save_as_template_body import ProjectGidSaveAsTemplateBody
from asana.models.project_gid_sections_body import ProjectGidSectionsBody
from asana.models.project_membership_base import ProjectMembershipBase
from asana.models.project_membership_compact import ProjectMembershipCompact
from asana.models.project_membership_compact_array import ProjectMembershipCompactArray
from asana.models.project_membership_compact_response import ProjectMembershipCompactResponse
from asana.models.project_membership_normal_response import ProjectMembershipNormalResponse
from asana.models.project_membership_normal_response_data import ProjectMembershipNormalResponseData
from asana.models.project_request import ProjectRequest
from asana.models.project_response import ProjectResponse
from asana.models.project_response_array import ProjectResponseArray
from asana.models.project_response_completed_by import ProjectResponseCompletedBy
from asana.models.project_response_created_from_template import ProjectResponseCreatedFromTemplate
from asana.models.project_response_data import ProjectResponseData
from asana.models.project_response_project_brief import ProjectResponseProjectBrief
from asana.models.project_response_team import ProjectResponseTeam
from asana.models.project_response_workspace import ProjectResponseWorkspace
from asana.models.project_save_as_template_request import ProjectSaveAsTemplateRequest
from asana.models.project_section_insert_request import ProjectSectionInsertRequest
from asana.models.project_status_base import ProjectStatusBase
from asana.models.project_status_compact import ProjectStatusCompact
from asana.models.project_status_request import ProjectStatusRequest
from asana.models.project_status_response import ProjectStatusResponse
from asana.models.project_status_response_array import ProjectStatusResponseArray
from asana.models.project_status_response_data import ProjectStatusResponseData
from asana.models.project_template_base import ProjectTemplateBase
from asana.models.project_template_base_requested_dates import ProjectTemplateBaseRequestedDates
from asana.models.project_template_base_requested_roles import ProjectTemplateBaseRequestedRoles
from asana.models.project_template_base_team import ProjectTemplateBaseTeam
from asana.models.project_template_compact import ProjectTemplateCompact
from asana.models.project_template_gid_instantiate_project_body import ProjectTemplateGidInstantiateProjectBody
from asana.models.project_template_instantiate_project_request import ProjectTemplateInstantiateProjectRequest
from asana.models.project_template_instantiate_project_request_requested_dates import ProjectTemplateInstantiateProjectRequestRequestedDates
from asana.models.project_template_instantiate_project_request_requested_roles import ProjectTemplateInstantiateProjectRequestRequestedRoles
from asana.models.project_template_response import ProjectTemplateResponse
from asana.models.project_template_response_array import ProjectTemplateResponseArray
from asana.models.project_template_response_data import ProjectTemplateResponseData
from asana.models.project_update_request import ProjectUpdateRequest
from asana.models.projects_body import ProjectsBody
from asana.models.projects_project_gid_body import ProjectsProjectGidBody
from asana.models.remove_custom_field_setting_request import RemoveCustomFieldSettingRequest
from asana.models.remove_followers_request import RemoveFollowersRequest
from asana.models.remove_members_request import RemoveMembersRequest
from asana.models.requested_role_request import RequestedRoleRequest
from asana.models.rule_trigger_gid_run_body import RuleTriggerGidRunBody
from asana.models.rule_trigger_request import RuleTriggerRequest
from asana.models.rule_trigger_response import RuleTriggerResponse
from asana.models.rule_trigger_response_data import RuleTriggerResponseData
from asana.models.section_base import SectionBase
from asana.models.section_compact import SectionCompact
from asana.models.section_gid_add_task_body import SectionGidAddTaskBody
from asana.models.section_request import SectionRequest
from asana.models.section_response import SectionResponse
from asana.models.section_response_array import SectionResponseArray
from asana.models.section_response_data import SectionResponseData
from asana.models.section_task_insert_request import SectionTaskInsertRequest
from asana.models.sections_insert_body import SectionsInsertBody
from asana.models.sections_section_gid_body import SectionsSectionGidBody
from asana.models.status_update_base import StatusUpdateBase
from asana.models.status_update_compact import StatusUpdateCompact
from asana.models.status_update_request import StatusUpdateRequest
from asana.models.status_update_response import StatusUpdateResponse
from asana.models.status_update_response_array import StatusUpdateResponseArray
from asana.models.status_update_response_data import StatusUpdateResponseData
from asana.models.status_update_response_parent import StatusUpdateResponseParent
from asana.models.status_updates_body import StatusUpdatesBody
from asana.models.stories_story_gid_body import StoriesStoryGidBody
from asana.models.story_base import StoryBase
from asana.models.story_compact import StoryCompact
from asana.models.story_request import StoryRequest
from asana.models.story_response import StoryResponse
from asana.models.story_response_array import StoryResponseArray
from asana.models.story_response_assignee import StoryResponseAssignee
from asana.models.story_response_custom_field import StoryResponseCustomField
from asana.models.story_response_data import StoryResponseData
from asana.models.story_response_dates import StoryResponseDates
from asana.models.story_response_old_dates import StoryResponseOldDates
from asana.models.story_response_old_enum_value import StoryResponseOldEnumValue
from asana.models.story_response_old_section import StoryResponseOldSection
from asana.models.story_response_previews import StoryResponsePreviews
from asana.models.story_response_project import StoryResponseProject
from asana.models.story_response_story import StoryResponseStory
from asana.models.story_response_tag import StoryResponseTag
from asana.models.story_response_target import StoryResponseTarget
from asana.models.story_response_task import StoryResponseTask
from asana.models.tag_base import TagBase
from asana.models.tag_compact import TagCompact
from asana.models.tag_request import TagRequest
from asana.models.tag_response import TagResponse
from asana.models.tag_response_array import TagResponseArray
from asana.models.tag_response_data import TagResponseData
from asana.models.tags_body import TagsBody
from asana.models.task_add_followers_request import TaskAddFollowersRequest
from asana.models.task_add_project_request import TaskAddProjectRequest
from asana.models.task_add_tag_request import TaskAddTagRequest
from asana.models.task_base import TaskBase
from asana.models.task_base_completed_by import TaskBaseCompletedBy
from asana.models.task_base_dependencies import TaskBaseDependencies
from asana.models.task_base_external import TaskBaseExternal
from asana.models.task_base_memberships import TaskBaseMemberships
from asana.models.task_base_section import TaskBaseSection
from asana.models.task_compact import TaskCompact
from asana.models.task_count_response import TaskCountResponse
from asana.models.task_count_response_data import TaskCountResponseData
from asana.models.task_duplicate_request import TaskDuplicateRequest
from asana.models.task_gid_add_dependencies_body import TaskGidAddDependenciesBody
from asana.models.task_gid_add_dependents_body import TaskGidAddDependentsBody
from asana.models.task_gid_add_followers_body import TaskGidAddFollowersBody
from asana.models.task_gid_add_project_body import TaskGidAddProjectBody
from asana.models.task_gid_add_tag_body import TaskGidAddTagBody
from asana.models.task_gid_duplicate_body import TaskGidDuplicateBody
from asana.models.task_gid_remove_dependencies_body import TaskGidRemoveDependenciesBody
from asana.models.task_gid_remove_dependents_body import TaskGidRemoveDependentsBody
from asana.models.task_gid_remove_followers_body import TaskGidRemoveFollowersBody
from asana.models.task_gid_remove_project_body import TaskGidRemoveProjectBody
from asana.models.task_gid_remove_tag_body import TaskGidRemoveTagBody
from asana.models.task_gid_set_parent_body import TaskGidSetParentBody
from asana.models.task_gid_stories_body import TaskGidStoriesBody
from asana.models.task_gid_subtasks_body import TaskGidSubtasksBody
from asana.models.task_gid_time_tracking_entries_body import TaskGidTimeTrackingEntriesBody
from asana.models.task_remove_followers_request import TaskRemoveFollowersRequest
from asana.models.task_remove_project_request import TaskRemoveProjectRequest
from asana.models.task_remove_tag_request import TaskRemoveTagRequest
from asana.models.task_request import TaskRequest
from asana.models.task_response import TaskResponse
from asana.models.task_response_array import TaskResponseArray
from asana.models.task_response_assignee_section import TaskResponseAssigneeSection
from asana.models.task_response_custom_fields import TaskResponseCustomFields
from asana.models.task_response_data import TaskResponseData
from asana.models.task_response_parent import TaskResponseParent
from asana.models.task_response_tags import TaskResponseTags
from asana.models.task_response_workspace import TaskResponseWorkspace
from asana.models.task_set_parent_request import TaskSetParentRequest
from asana.models.tasks_body import TasksBody
from asana.models.tasks_task_gid_body import TasksTaskGidBody
from asana.models.team_add_user_request import TeamAddUserRequest
from asana.models.team_base import TeamBase
from asana.models.team_compact import TeamCompact
from asana.models.team_gid_add_user_body import TeamGidAddUserBody
from asana.models.team_gid_projects_body import TeamGidProjectsBody
from asana.models.team_gid_remove_user_body import TeamGidRemoveUserBody
from asana.models.team_membership_base import TeamMembershipBase
from asana.models.team_membership_compact import TeamMembershipCompact
from asana.models.team_membership_response import TeamMembershipResponse
from asana.models.team_membership_response_array import TeamMembershipResponseArray
from asana.models.team_membership_response_data import TeamMembershipResponseData
from asana.models.team_remove_user_request import TeamRemoveUserRequest
from asana.models.team_request import TeamRequest
from asana.models.team_response import TeamResponse
from asana.models.team_response_array import TeamResponseArray
from asana.models.team_response_data import TeamResponseData
from asana.models.team_response_organization import TeamResponseOrganization
from asana.models.teams_body import TeamsBody
from asana.models.teams_team_gid_body import TeamsTeamGidBody
from asana.models.template_role import TemplateRole
from asana.models.time_period_base import TimePeriodBase
from asana.models.time_period_compact import TimePeriodCompact
from asana.models.time_period_response import TimePeriodResponse
from asana.models.time_period_response_array import TimePeriodResponseArray
from asana.models.time_period_response_data import TimePeriodResponseData
from asana.models.time_tracking_entries_time_tracking_entry_gid_body import TimeTrackingEntriesTimeTrackingEntryGidBody
from asana.models.time_tracking_entry_base import TimeTrackingEntryBase
from asana.models.time_tracking_entry_base_data import TimeTrackingEntryBaseData
from asana.models.time_tracking_entry_compact import TimeTrackingEntryCompact
from asana.models.time_tracking_entry_compact_array import TimeTrackingEntryCompactArray
from asana.models.update_time_tracking_entry_request import UpdateTimeTrackingEntryRequest
from asana.models.user_base import UserBase
from asana.models.user_base_response import UserBaseResponse
from asana.models.user_base_response_data import UserBaseResponseData
from asana.models.user_base_response_photo import UserBaseResponsePhoto
from asana.models.user_compact import UserCompact
from asana.models.user_request import UserRequest
from asana.models.user_response import UserResponse
from asana.models.user_response_array import UserResponseArray
from asana.models.user_response_data import UserResponseData
from asana.models.user_task_list_base import UserTaskListBase
from asana.models.user_task_list_compact import UserTaskListCompact
from asana.models.user_task_list_request import UserTaskListRequest
from asana.models.user_task_list_response import UserTaskListResponse
from asana.models.user_task_list_response_data import UserTaskListResponseData
from asana.models.webhook_compact import WebhookCompact
from asana.models.webhook_compact_resource import WebhookCompactResource
from asana.models.webhook_filter import WebhookFilter
from asana.models.webhook_request import WebhookRequest
from asana.models.webhook_request_filters import WebhookRequestFilters
from asana.models.webhook_response import WebhookResponse
from asana.models.webhook_response_array import WebhookResponseArray
from asana.models.webhook_response_data import WebhookResponseData
from asana.models.webhook_update_request import WebhookUpdateRequest
from asana.models.webhooks_body import WebhooksBody
from asana.models.webhooks_webhook_gid_body import WebhooksWebhookGidBody
from asana.models.workspace_add_user_request import WorkspaceAddUserRequest
from asana.models.workspace_base import WorkspaceBase
from asana.models.workspace_compact import WorkspaceCompact
from asana.models.workspace_gid_add_user_body import WorkspaceGidAddUserBody
from asana.models.workspace_gid_projects_body import WorkspaceGidProjectsBody
from asana.models.workspace_gid_remove_user_body import WorkspaceGidRemoveUserBody
from asana.models.workspace_gid_tags_body import WorkspaceGidTagsBody
from asana.models.workspace_membership_base import WorkspaceMembershipBase
from asana.models.workspace_membership_compact import WorkspaceMembershipCompact
from asana.models.workspace_membership_request import WorkspaceMembershipRequest
from asana.models.workspace_membership_response import WorkspaceMembershipResponse
from asana.models.workspace_membership_response_array import WorkspaceMembershipResponseArray
from asana.models.workspace_membership_response_data import WorkspaceMembershipResponseData
from asana.models.workspace_membership_response_user_task_list import WorkspaceMembershipResponseUserTaskList
from asana.models.workspace_membership_response_vacation_dates import WorkspaceMembershipResponseVacationDates
from asana.models.workspace_remove_user_request import WorkspaceRemoveUserRequest
from asana.models.workspace_request import WorkspaceRequest
from asana.models.workspace_response import WorkspaceResponse
from asana.models.workspace_response_array import WorkspaceResponseArray
from asana.models.workspace_response_data import WorkspaceResponseData
from asana.models.workspaces_workspace_gid_body import WorkspacesWorkspaceGidBody



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TagResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'color': 'str',
        'notes': 'str',
        'created_at': 'datetime',
        'followers': 'list[CustomFieldResponsePeopleValue]',
        'workspace': 'GoalResponseWorkspace',
        'permalink_url': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'color': 'color',
        'notes': 'notes',
        'created_at': 'created_at',
        'followers': 'followers',
        'workspace': 'workspace',
        'permalink_url': 'permalink_url'
    }

    def __init__(self, gid=None, resource_type=None, name=None, color=None, notes=None, created_at=None, followers=None, workspace=None, permalink_url=None):  # noqa: E501
        """TagResponse - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._color = None
        self._notes = None
        self._created_at = None
        self._followers = None
        self._workspace = None
        self._permalink_url = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if color is not None:
            self.color = color
        if notes is not None:
            self.notes = notes
        if created_at is not None:
            self.created_at = created_at
        if followers is not None:
            self.followers = followers
        if workspace is not None:
            self.workspace = workspace
        if permalink_url is not None:
            self.permalink_url = permalink_url

    @property
    def gid(self):
        """Gets the gid of this TagResponse.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this TagResponse.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this TagResponse.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this TagResponse.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this TagResponse.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this TagResponse.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this TagResponse.  # noqa: E501

        Name of the tag. This is generally a short sentence fragment that fits on a line in the UI for maximum readability. However, it can be longer.  # noqa: E501

        :return: The name of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TagResponse.

        Name of the tag. This is generally a short sentence fragment that fits on a line in the UI for maximum readability. However, it can be longer.  # noqa: E501

        :param name: The name of this TagResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def color(self):
        """Gets the color of this TagResponse.  # noqa: E501

        Color of the tag.  # noqa: E501

        :return: The color of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this TagResponse.

        Color of the tag.  # noqa: E501

        :param color: The color of this TagResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["dark-pink", "dark-green", "dark-blue", "dark-red", "dark-teal", "dark-brown", "dark-orange", "dark-purple", "dark-warm-gray", "light-pink", "light-green", "light-blue", "light-red", "light-teal", "light-brown", "light-orange", "light-purple", "light-warm-gray", ""]  # noqa: E501
        if color not in allowed_values:
            raise ValueError(
                "Invalid value for `color` ({0}), must be one of {1}"  # noqa: E501
                .format(color, allowed_values)
            )

        self._color = color

    @property
    def notes(self):
        """Gets the notes of this TagResponse.  # noqa: E501

        Free-form textual information associated with the tag (i.e. its description).  # noqa: E501

        :return: The notes of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this TagResponse.

        Free-form textual information associated with the tag (i.e. its description).  # noqa: E501

        :param notes: The notes of this TagResponse.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def created_at(self):
        """Gets the created_at of this TagResponse.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this TagResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TagResponse.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this TagResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def followers(self):
        """Gets the followers of this TagResponse.  # noqa: E501

        Array of users following this tag.  # noqa: E501

        :return: The followers of this TagResponse.  # noqa: E501
        :rtype: list[CustomFieldResponsePeopleValue]
        """
        return self._followers

    @followers.setter
    def followers(self, followers):
        """Sets the followers of this TagResponse.

        Array of users following this tag.  # noqa: E501

        :param followers: The followers of this TagResponse.  # noqa: E501
        :type: list[CustomFieldResponsePeopleValue]
        """

        self._followers = followers

    @property
    def workspace(self):
        """Gets the workspace of this TagResponse.  # noqa: E501


        :return: The workspace of this TagResponse.  # noqa: E501
        :rtype: GoalResponseWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this TagResponse.


        :param workspace: The workspace of this TagResponse.  # noqa: E501
        :type: GoalResponseWorkspace
        """

        self._workspace = workspace

    @property
    def permalink_url(self):
        """Gets the permalink_url of this TagResponse.  # noqa: E501

        A url that points directly to the object within Asana.  # noqa: E501

        :return: The permalink_url of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._permalink_url

    @permalink_url.setter
    def permalink_url(self, permalink_url):
        """Sets the permalink_url of this TagResponse.

        A url that points directly to the object within Asana.  # noqa: E501

        :param permalink_url: The permalink_url of this TagResponse.  # noqa: E501
        :type: str
        """

        self._permalink_url = permalink_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TagResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.tasks_api import TasksApi  # noqa: E501
from asana.rest import ApiException


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_dependencies_for_task(self):
        """Test case for add_dependencies_for_task

        Set dependencies for a task  # noqa: E501
        """
        pass

    def test_add_dependents_for_task(self):
        """Test case for add_dependents_for_task

        Set dependents for a task  # noqa: E501
        """
        pass

    def test_add_followers_for_task(self):
        """Test case for add_followers_for_task

        Add followers to a task  # noqa: E501
        """
        pass

    def test_add_project_for_task(self):
        """Test case for add_project_for_task

        Add a project to a task  # noqa: E501
        """
        pass

    def test_add_tag_for_task(self):
        """Test case for add_tag_for_task

        Add a tag to a task  # noqa: E501
        """
        pass

    def test_create_subtask_for_task(self):
        """Test case for create_subtask_for_task

        Create a subtask  # noqa: E501
        """
        pass

    def test_create_task(self):
        """Test case for create_task

        Create a task  # noqa: E501
        """
        pass

    def test_delete_task(self):
        """Test case for delete_task

        Delete a task  # noqa: E501
        """
        pass

    def test_duplicate_task(self):
        """Test case for duplicate_task

        Duplicate a task  # noqa: E501
        """
        pass

    def test_get_dependencies_for_task(self):
        """Test case for get_dependencies_for_task

        Get dependencies from a task  # noqa: E501
        """
        pass

    def test_get_dependents_for_task(self):
        """Test case for get_dependents_for_task

        Get dependents from a task  # noqa: E501
        """
        pass

    def test_get_subtasks_for_task(self):
        """Test case for get_subtasks_for_task

        Get subtasks from a task  # noqa: E501
        """
        pass

    def test_get_task(self):
        """Test case for get_task

        Get a task  # noqa: E501
        """
        pass

    def test_get_tasks(self):
        """Test case for get_tasks

        Get multiple tasks  # noqa: E501
        """
        pass

    def test_get_tasks_for_project(self):
        """Test case for get_tasks_for_project

        Get tasks from a project  # noqa: E501
        """
        pass

    def test_get_tasks_for_section(self):
        """Test case for get_tasks_for_section

        Get tasks from a section  # noqa: E501
        """
        pass

    def test_get_tasks_for_tag(self):
        """Test case for get_tasks_for_tag

        Get tasks from a tag  # noqa: E501
        """
        pass

    def test_get_tasks_for_user_task_list(self):
        """Test case for get_tasks_for_user_task_list

        Get tasks from a user task list  # noqa: E501
        """
        pass

    def test_remove_dependencies_for_task(self):
        """Test case for remove_dependencies_for_task

        Unlink dependencies from a task  # noqa: E501
        """
        pass

    def test_remove_dependents_for_task(self):
        """Test case for remove_dependents_for_task

        Unlink dependents from a task  # noqa: E501
        """
        pass

    def test_remove_follower_for_task(self):
        """Test case for remove_follower_for_task

        Remove followers from a task  # noqa: E501
        """
        pass

    def test_remove_project_for_task(self):
        """Test case for remove_project_for_task

        Remove a project from a task  # noqa: E501
        """
        pass

    def test_remove_tag_for_task(self):
        """Test case for remove_tag_for_task

        Remove a tag from a task  # noqa: E501
        """
        pass

    def test_search_tasks_for_workspace(self):
        """Test case for search_tasks_for_workspace

        Search tasks in a workspace  # noqa: E501
        """
        pass

    def test_set_parent_for_task(self):
        """Test case for set_parent_for_task

        Set the parent of a task  # noqa: E501
        """
        pass

    def test_update_task(self):
        """Test case for update_task

        Update a task  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.users_api import UsersApi  # noqa: E501
from asana.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_favorites_for_user(self):
        """Test case for get_favorites_for_user

        Get a user's favorites  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get a user  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Get multiple users  # noqa: E501
        """
        pass

    def test_get_users_for_team(self):
        """Test case for get_users_for_team

        Get users in a team  # noqa: E501
        """
        pass

    def test_get_users_for_workspace(self):
        """Test case for get_users_for_workspace

        Get users in a workspace or organization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.models.custom_field_setting_response_custom_field import CustomFieldSettingResponseCustomField  # noqa: E501
from asana.rest import ApiException


class TestCustomFieldSettingResponseCustomField(unittest.TestCase):
    """CustomFieldSettingResponseCustomField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomFieldSettingResponseCustomField(self):
        """Test CustomFieldSettingResponseCustomField"""
        # FIXME: construct object with mandatory attributes with example values
        # model = asana.models.custom_field_setting_response_custom_field.CustomFieldSettingResponseCustomField()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
